# pytronix

Written and Maintained by Matteo Vidali - [mmvidali@gmail.com](mmvidali@gmail.com)

a VISA/VXI11 based library to control tektronix scopes

Checkout the [PyPi Project](https://pypi.org/project/pytektronix/#description)

See the official [PyTektronix Documentation](https://matteovidali.github.io/pytektronix/)

To install, run:

```bash
    pip install pytektronix
```
